==> rabino-1.0.5.tar.gz: rabino-1.0.5/setup.py <==
import os
import re
from setuptools import setup

requires = ["pycryptodome","websocket_client","requests","rubiran","Pillow","libraryshad","requests","pyrubika"]
_long_description = """


### How to import the rubino library

``` bash
from rabino import rubino
```

### How to install the library

``` bash
pip install rabino==1.0.5
```

### My ID in Rubika

``` bash
@professor_102
```
## And My ID Channel in Rubika

``` bash
@python_java_source 
```
"""

setup(
    name = "rabino",
    version = "1.0.5",
    author = "mamadcoder",
    author_email = "x.coder.2721@gmail.com",
    description = ("Rubika Library Bot"),
    license = "MIT",
    keywords = ["rubika","bot","robot","library","rubikalib","rubikalib.ml","rubikalib.ir","rabino","Rabino","libraryrobiran","Rubika","Python","rubiran","pyrubi","telebot"],
    url = "https://github.com/pypa/sampleproject",
    packages=['rabino'],
    long_description=_long_description,
    classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    "Programming Language :: Python :: Implementation :: PyPy",
    'Programming Language :: Python :: 3',   
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    ],
)

==> rabino-2.0.0.tar.gz: rabino-2.0.0/setup.py <==
import os
import re
from setuptools import setup

requires = ["aiohttp","asyncio","tqdm","pathlib","rubiran"]
_long_description = """


### How to import the rubino library

``` bash
from rabino import rubino
```

## An example:
```python
from rabino import rubino
import asyncio
async def main():
    async with rubino("auth") as bot:
        
        data = await bot.search_username("@super_god1")
        print(data)
asyncio.run(main())
```


### How to install the library

``` bash
pip install rabino==2.0.0
```

### My ID in Telegram

``` bash
https://t.me/RMSource
```
## And My ID Channel in Telegram

``` bash
https://t.me/RMSource
```
### My site
<a href="https://anime.api-vison.workers.dev">سایت ما</a>
"""

setup(
    name = "rabino",
    version = "2.0.0",
    author = "mamadcoder",
    author_email = "x.coder.2721@gmail.com",
    description = ("Rubika Library Bot"),
    license = "MIT",
    keywords = ["rubika","bot","robot","library","rubikalib","rubikalib.ml","rubikalib.ir","rabino","Rabino","libraryrobiran","Rubika","Python","rubiran","pyrubi","telebot"],
    url = "https://github.com/pypa/sampleproject",
    packages=['rabino'],
    long_description=_long_description,
    long_description_content_type="text/markdown",
    classifiers=[
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    "Programming Language :: Python :: Implementation :: PyPy",
    'Programming Language :: Python :: 3',   
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    ],
)
